from setuptools import setup

setup(name='dsnd_prob_vd',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['dsnd_prob_gauss_binom'],
      author = 'David Yacoub',
      author_email= 'daveshtine2010@yahoo.com',
      zip_safe=False)
